==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/component/impl/C_CSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.component.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.architecture.component.ComponentDefinitionSet;
import io.ciera.tool.sql.architecture.component.impl.ComponentDefinitionSetImpl;
import io.ciera.tool.sql.ooaofooa.body.BodyInComponentSet;
import io.ciera.tool.sql.ooaofooa.body.impl.BodyInComponentSetImpl;
import io.ciera.tool.sql.ooaofooa.component.C_C;
import io.ciera.tool.sql.ooaofooa.component.C_CSet;
import io.ciera.tool.sql.ooaofooa.component.C_POSet;
import io.ciera.tool.sql.ooaofooa.component.componentlibrary.ComponentReferenceSet;
import io.ciera.tool.sql.ooaofooa.component.componentlibrary.impl.ComponentReferenceSetImpl;
import io.ciera.tool.sql.ooaofooa.component.impl.C_POSetImpl;
import io.ciera.tool.sql.ooaofooa.instance.ComponentInstanceSet;
import io.ciera.tool.sql.ooaofooa.instance.impl.ComponentInstanceSetImpl;
import io.ciera.tool.sql.ooaofooa.interaction.ComponentParticipantSet;
import io.ciera.tool.sql.ooaofooa.interaction.impl.ComponentParticipantSetImpl;
import io.ciera.tool.sql.ooaofooa.packageableelement.ComponentResultSetSet;
import io.ciera.tool.sql.ooaofooa.packageableelement.ComponentVisibilitySet;
import io.ciera.tool.sql.ooaofooa.packageableelement.PackageableElementSet;
import io.ciera.tool.sql.ooaofooa.packageableelement.impl.ComponentResultSetSetImpl;
import io.ciera.tool.sql.ooaofooa.packageableelement.impl.ComponentVisibilitySetImpl;
import io.ciera.tool.sql.ooaofooa.packageableelement.impl.PackageableElementSetImpl;
import io.ciera.tool.sql.ooaofooa.persistenceassociations.DelegationInComponentSet;
import io.ciera.tool.sql.ooaofooa.persistenceassociations.SatisfactionInComponentSet;
import io.ciera.tool.sql.ooaofooa.persistenceassociations.impl.DelegationInComponentSetImpl;
import io.ciera.tool.sql.ooaofooa.persistenceassociations.impl.SatisfactionInComponentSetImpl;

import java.util.Arrays;
import java.util.List;


public class C_CSetImpl extends InstanceSet<C_CSet,C_C> implements C_CSet {

    // attributes
    @Override
    public void setRoot_Package_IDdeprecated( UniqueId m_Root_Package_IDdeprecated ) throws XtumlException {
        for ( C_C c_c : this ) c_c.setRoot_Package_IDdeprecated( m_Root_Package_IDdeprecated );
    }
    @Override
    public void setDescrip( String m_Descrip ) throws XtumlException {
        for ( C_C c_c : this ) c_c.setDescrip( m_Descrip );
    }
    @Override
    public void setMult( int m_Mult ) throws XtumlException {
        for ( C_C c_c : this ) c_c.setMult( m_Mult );
    }
    @Override
    public void setId( UniqueId ref_Id ) throws XtumlException {
        for ( C_C c_c : this ) c_c.setId( ref_Id );
    }
    @Override
    public void setPackage_IDdeprecated( UniqueId m_Package_IDdeprecated ) throws XtumlException {
        for ( C_C c_c : this ) c_c.setPackage_IDdeprecated( m_Package_IDdeprecated );
    }
    @Override
    public void setName( String m_Name ) throws XtumlException {
        for ( C_C c_c : this ) c_c.setName( m_Name );
    }
    @Override
    public void setNestedComponent_IDdeprecated( UniqueId m_NestedComponent_IDdeprecated ) throws XtumlException {
        for ( C_C c_c : this ) c_c.setNestedComponent_IDdeprecated( m_NestedComponent_IDdeprecated );
    }
    @Override
    public void setRealized_Class_Path( String m_Realized_Class_Path ) throws XtumlException {
        for ( C_C c_c : this ) c_c.setRealized_Class_Path( m_Realized_Class_Path );
    }
    @Override
    public void setIsRealized( boolean m_isRealized ) throws XtumlException {
        for ( C_C c_c : this ) c_c.setIsRealized( m_isRealized );
    }


    // selections
    @Override
    public ComponentInstanceSet R2955_instance_being_verified_by_ComponentInstance() throws XtumlException {
        ComponentInstanceSet componentinstanceset = new ComponentInstanceSetImpl();
        for ( C_C c_c : this ) componentinstanceset.addAll( c_c.R2955_instance_being_verified_by_ComponentInstance() );
        return componentinstanceset;
    }
    @Override
    public C_POSet R4010_communicates_through_C_PO() throws XtumlException {
        C_POSet c_poset = new C_POSetImpl();
        for ( C_C c_c : this ) c_poset.addAll( c_c.R4010_communicates_through_C_PO() );
        return c_poset;
    }
    @Override
    public ComponentReferenceSet R4201_is_represented_by_ComponentReference() throws XtumlException {
        ComponentReferenceSet componentreferenceset = new ComponentReferenceSetImpl();
        for ( C_C c_c : this ) componentreferenceset.addAll( c_c.R4201_is_represented_by_ComponentReference() );
        return componentreferenceset;
    }
    @Override
    public ComponentReferenceSet R4205_nests_ComponentReference() throws XtumlException {
        ComponentReferenceSet componentreferenceset = new ComponentReferenceSetImpl();
        for ( C_C c_c : this ) componentreferenceset.addAll( c_c.R4205_nests_ComponentReference() );
        return componentreferenceset;
    }
    @Override
    public ComponentDefinitionSet R4573_is_basis_for_ComponentDefinition() throws XtumlException {
        ComponentDefinitionSet componentdefinitionset = new ComponentDefinitionSetImpl();
        for ( C_C c_c : this ) componentdefinitionset.add( c_c.R4573_is_basis_for_ComponentDefinition() );
        return componentdefinitionset;
    }
    @Override
    public BodyInComponentSet R694_has_declared_BodyInComponent() throws XtumlException {
        BodyInComponentSet bodyincomponentset = new BodyInComponentSetImpl();
        for ( C_C c_c : this ) bodyincomponentset.addAll( c_c.R694_has_declared_BodyInComponent() );
        return bodyincomponentset;
    }
    @Override
    public PackageableElementSet R8001_is_a_PackageableElement() throws XtumlException {
        PackageableElementSet packageableelementset = new PackageableElementSetImpl();
        for ( C_C c_c : this ) packageableelementset.add( c_c.R8001_is_a_PackageableElement() );
        return packageableelementset;
    }
    @Override
    public PackageableElementSet R8003_contains_PackageableElement() throws XtumlException {
        PackageableElementSet packageableelementset = new PackageableElementSetImpl();
        for ( C_C c_c : this ) packageableelementset.addAll( c_c.R8003_contains_PackageableElement() );
        return packageableelementset;
    }
    @Override
    public ComponentVisibilitySet R8004_has_visibility_of_ComponentVisibility() throws XtumlException {
        ComponentVisibilitySet componentvisibilityset = new ComponentVisibilitySetImpl();
        for ( C_C c_c : this ) componentvisibilityset.addAll( c_c.R8004_has_visibility_of_ComponentVisibility() );
        return componentvisibilityset;
    }
    @Override
    public ComponentResultSetSet R8007_holds_ComponentResultSet() throws XtumlException {
        ComponentResultSetSet componentresultsetset = new ComponentResultSetSetImpl();
        for ( C_C c_c : this ) componentresultsetset.addAll( c_c.R8007_holds_ComponentResultSet() );
        return componentresultsetset;
    }
    @Override
    public SatisfactionInComponentSet R9000_SatisfactionInComponent() throws XtumlException {
        SatisfactionInComponentSet satisfactionincomponentset = new SatisfactionInComponentSetImpl();
        for ( C_C c_c : this ) satisfactionincomponentset.addAll( c_c.R9000_SatisfactionInComponent() );
        return satisfactionincomponentset;
    }
    @Override
    public DelegationInComponentSet R9002_DelegationInComponent() throws XtumlException {
        DelegationInComponentSet delegationincomponentset = new DelegationInComponentSetImpl();
        for ( C_C c_c : this ) delegationincomponentset.addAll( c_c.R9002_DelegationInComponent() );
        return delegationincomponentset;
    }
    @Override
    public ComponentParticipantSet R955_ComponentParticipant() throws XtumlException {
        ComponentParticipantSet componentparticipantset = new ComponentParticipantSetImpl();
        for ( C_C c_c : this ) componentparticipantset.addAll( c_c.R955_ComponentParticipant() );
        return componentparticipantset;
    }


    @Override
    public C_C nullElement() {
        return C_CImpl.EMPTY_C_C;
    }

    @Override
    public C_CSet emptySet() {
      return new C_CSetImpl();
    }

    @Override
    public C_CSet value() {
        return this;
    }

    @Override
    public List<C_C> elements() {
        C_C[] elements = toArray(new C_C[0]);
        Arrays.sort(elements, (a, b) -> {
            try {
                return a.getName().compareTo(b.getName());
            } catch (XtumlException e) { return 0; }
        });
        return Arrays.asList(elements);
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/component/impl/C_CSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.component.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.architecture.component.ComponentDefinitionSet;
import io.ciera.tool.sql.architecture.component.impl.ComponentDefinitionSetImpl;
import io.ciera.tool.sql.ooaofooa.body.BodyInComponentSet;
import io.ciera.tool.sql.ooaofooa.body.impl.BodyInComponentSetImpl;
import io.ciera.tool.sql.ooaofooa.component.C_C;
import io.ciera.tool.sql.ooaofooa.component.C_CSet;
import io.ciera.tool.sql.ooaofooa.component.C_POSet;
import io.ciera.tool.sql.ooaofooa.component.componentlibrary.ComponentReferenceSet;
import io.ciera.tool.sql.ooaofooa.component.componentlibrary.impl.ComponentReferenceSetImpl;
import io.ciera.tool.sql.ooaofooa.component.impl.C_POSetImpl;
import io.ciera.tool.sql.ooaofooa.instance.ComponentInstanceSet;
import io.ciera.tool.sql.ooaofooa.instance.impl.ComponentInstanceSetImpl;
import io.ciera.tool.sql.ooaofooa.interaction.ComponentParticipantSet;
import io.ciera.tool.sql.ooaofooa.interaction.impl.ComponentParticipantSetImpl;
import io.ciera.tool.sql.ooaofooa.packageableelement.ComponentResultSetSet;
import io.ciera.tool.sql.ooaofooa.packageableelement.ComponentVisibilitySet;
import io.ciera.tool.sql.ooaofooa.packageableelement.PackageableElementSet;
import io.ciera.tool.sql.ooaofooa.packageableelement.impl.ComponentResultSetSetImpl;
import io.ciera.tool.sql.ooaofooa.packageableelement.impl.ComponentVisibilitySetImpl;
import io.ciera.tool.sql.ooaofooa.packageableelement.impl.PackageableElementSetImpl;
import io.ciera.tool.sql.ooaofooa.persistenceassociations.DelegationInComponentSet;
import io.ciera.tool.sql.ooaofooa.persistenceassociations.SatisfactionInComponentSet;
import io.ciera.tool.sql.ooaofooa.persistenceassociations.impl.DelegationInComponentSetImpl;
import io.ciera.tool.sql.ooaofooa.persistenceassociations.impl.SatisfactionInComponentSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class C_CSetImpl extends InstanceSet<C_CSet,C_C> implements C_CSet {

    public C_CSetImpl() {
    }

    public C_CSetImpl(Comparator<? super C_C> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setRoot_Package_IDdeprecated( UniqueId m_Root_Package_IDdeprecated ) throws XtumlException {
        for ( C_C c_c : this ) c_c.setRoot_Package_IDdeprecated( m_Root_Package_IDdeprecated );
    }
    @Override
    public void setId( UniqueId ref_Id ) throws XtumlException {
        for ( C_C c_c : this ) c_c.setId( ref_Id );
    }
    @Override
    public void setIsRealized( boolean m_isRealized ) throws XtumlException {
        for ( C_C c_c : this ) c_c.setIsRealized( m_isRealized );
    }
    @Override
    public void setPackage_IDdeprecated( UniqueId m_Package_IDdeprecated ) throws XtumlException {
        for ( C_C c_c : this ) c_c.setPackage_IDdeprecated( m_Package_IDdeprecated );
    }
    @Override
    public void setName( String m_Name ) throws XtumlException {
        for ( C_C c_c : this ) c_c.setName( m_Name );
    }
    @Override
    public void setNestedComponent_IDdeprecated( UniqueId m_NestedComponent_IDdeprecated ) throws XtumlException {
        for ( C_C c_c : this ) c_c.setNestedComponent_IDdeprecated( m_NestedComponent_IDdeprecated );
    }
    @Override
    public void setMult( int m_Mult ) throws XtumlException {
        for ( C_C c_c : this ) c_c.setMult( m_Mult );
    }
    @Override
    public void setDescrip( String m_Descrip ) throws XtumlException {
        for ( C_C c_c : this ) c_c.setDescrip( m_Descrip );
    }
    @Override
    public void setRealized_Class_Path( String m_Realized_Class_Path ) throws XtumlException {
        for ( C_C c_c : this ) c_c.setRealized_Class_Path( m_Realized_Class_Path );
    }


    // selections
    @Override
    public ComponentInstanceSet R2955_instance_being_verified_by_ComponentInstance() throws XtumlException {
        ComponentInstanceSet componentinstanceset = new ComponentInstanceSetImpl();
        for ( C_C c_c : this ) componentinstanceset.addAll( c_c.R2955_instance_being_verified_by_ComponentInstance() );
        return componentinstanceset;
    }
    @Override
    public C_POSet R4010_communicates_through_C_PO() throws XtumlException {
        C_POSet c_poset = new C_POSetImpl();
        for ( C_C c_c : this ) c_poset.addAll( c_c.R4010_communicates_through_C_PO() );
        return c_poset;
    }
    @Override
    public ComponentReferenceSet R4201_is_represented_by_ComponentReference() throws XtumlException {
        ComponentReferenceSet componentreferenceset = new ComponentReferenceSetImpl();
        for ( C_C c_c : this ) componentreferenceset.addAll( c_c.R4201_is_represented_by_ComponentReference() );
        return componentreferenceset;
    }
    @Override
    public ComponentReferenceSet R4205_nests_ComponentReference() throws XtumlException {
        ComponentReferenceSet componentreferenceset = new ComponentReferenceSetImpl();
        for ( C_C c_c : this ) componentreferenceset.addAll( c_c.R4205_nests_ComponentReference() );
        return componentreferenceset;
    }
    @Override
    public ComponentDefinitionSet R4573_is_basis_for_ComponentDefinition() throws XtumlException {
        ComponentDefinitionSet componentdefinitionset = new ComponentDefinitionSetImpl();
        for ( C_C c_c : this ) componentdefinitionset.add( c_c.R4573_is_basis_for_ComponentDefinition() );
        return componentdefinitionset;
    }
    @Override
    public BodyInComponentSet R694_has_declared_BodyInComponent() throws XtumlException {
        BodyInComponentSet bodyincomponentset = new BodyInComponentSetImpl();
        for ( C_C c_c : this ) bodyincomponentset.addAll( c_c.R694_has_declared_BodyInComponent() );
        return bodyincomponentset;
    }
    @Override
    public PackageableElementSet R8001_is_a_PackageableElement() throws XtumlException {
        PackageableElementSet packageableelementset = new PackageableElementSetImpl();
        for ( C_C c_c : this ) packageableelementset.add( c_c.R8001_is_a_PackageableElement() );
        return packageableelementset;
    }
    @Override
    public PackageableElementSet R8003_contains_PackageableElement() throws XtumlException {
        PackageableElementSet packageableelementset = new PackageableElementSetImpl();
        for ( C_C c_c : this ) packageableelementset.addAll( c_c.R8003_contains_PackageableElement() );
        return packageableelementset;
    }
    @Override
    public ComponentVisibilitySet R8004_has_visibility_of_ComponentVisibility() throws XtumlException {
        ComponentVisibilitySet componentvisibilityset = new ComponentVisibilitySetImpl();
        for ( C_C c_c : this ) componentvisibilityset.addAll( c_c.R8004_has_visibility_of_ComponentVisibility() );
        return componentvisibilityset;
    }
    @Override
    public ComponentResultSetSet R8007_holds_ComponentResultSet() throws XtumlException {
        ComponentResultSetSet componentresultsetset = new ComponentResultSetSetImpl();
        for ( C_C c_c : this ) componentresultsetset.addAll( c_c.R8007_holds_ComponentResultSet() );
        return componentresultsetset;
    }
    @Override
    public SatisfactionInComponentSet R9000_SatisfactionInComponent() throws XtumlException {
        SatisfactionInComponentSet satisfactionincomponentset = new SatisfactionInComponentSetImpl();
        for ( C_C c_c : this ) satisfactionincomponentset.addAll( c_c.R9000_SatisfactionInComponent() );
        return satisfactionincomponentset;
    }
    @Override
    public DelegationInComponentSet R9002_DelegationInComponent() throws XtumlException {
        DelegationInComponentSet delegationincomponentset = new DelegationInComponentSetImpl();
        for ( C_C c_c : this ) delegationincomponentset.addAll( c_c.R9002_DelegationInComponent() );
        return delegationincomponentset;
    }
    @Override
    public ComponentParticipantSet R955_ComponentParticipant() throws XtumlException {
        ComponentParticipantSet componentparticipantset = new ComponentParticipantSetImpl();
        for ( C_C c_c : this ) componentparticipantset.addAll( c_c.R955_ComponentParticipant() );
        return componentparticipantset;
    }


    @Override
    public C_C nullElement() {
        return C_CImpl.EMPTY_C_C;
    }

    @Override
    public C_CSet emptySet() {
      return new C_CSetImpl();
    }

    @Override
    public C_CSet emptySet(Comparator<? super C_C> comp) {
      return new C_CSetImpl(comp);
    }

    @Override
    public C_CSet value() {
        return this;
    }

    @Override
    public List<C_C> elements() {
        C_C[] elements = toArray(new C_C[0]);
        Arrays.sort(elements, (a, b) -> {
            try {
                return a.getName().compareTo(b.getName());
            } catch (XtumlException e) { return 0; }
        });
        return Arrays.asList(elements);
    }

}
